Estimation of signals, rank of signals.
StepWiseSVD(Y, threshold=NULL, B=1000, level=0.02, methods='kmeans',
u_threshold=NULL, v_threshold=NULL, sparse=TRUE)
ScreeNot(Y, r1)
GetRank(Y, r1, type=c("1","2"), level=0.1, B=500)
signal_value(d, svr)
signal_vector(k1, k2, d1, d2, svr, left=TRUE)StepWiseSVD performs step-wise SVD to denoise and returns decomposed strcuture,
ScreeNot performs ScreeNot to denoise and returns decomposed strcuture,
GetRank gives rank of signals.
signal_value gives corrected signal eigenvalue from SVD result,
signal_vector gives limiting inner product between signal vector and corresponding signal-plus-noise vector.
matrix to be denoised.
repeat time of simulations.
threshold used in determining rank of signal.
significance level in determing ranks.
methods used in determining sparse structure.
thresholds used in determining sparse structure if kmeans is not used.
whether signals have sparse structure.
upper bound of rank.
type of test.
k-th eigenvector.
eigenvalues of corresponding signal matrix
whether to use left singular vectors.
ndf/ndim of Y.
Xiucai Ding, Yichen Hu
StepWiseSVD works well in sparse setting and requires i.i.d normal noise and a lot simulation time.SreeNot is to pick the best TSVD result so works well in general setting.
When using signal-plus-noise related limits, make sure they are limits of signal-related values or vectors.
[1] Ding, X. (2020). High dimensional deformed rectangular matrices with applications in matrix denoising. Bernoulli, 26(1), 387-417.
[2] Donoho, D. L., Gavish, M., & Romanov, E. (2020). Screenot: Exact mse-optimal singular value thresholding in correlated noise. arXiv preprint arXiv:2009.12297.
[3] Ding, X., & Yang, F. (2022). Tracy-Widom distribution for heterogeneous Gram matrices with applications in signal detection. IEEE Transactions on Information Theory, vol. 68, no. 10, pp. 6682-6715.